@@ -113,22 +113,22 @@ void MainWindow::connectSignals()
 
 void MainWindow::on_pushButtonSwap_clicked()
 {
-    m_process->start("sh opt/flopswap/script/swapswitch.sh");
+    m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
 }
 
 void MainWindow::on_pushButtonEject_clicked()
 {
-    m_process->start("sh opt/flopswap/script/swapswitchejectsd.sh");
+    m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
 }
 
 void MainWindow::on_pushButtonGet_clicked()
 {
-    m_process->start("sh opt/flopswap/script/catprocswap.sh");
+    m_process->start("sudo /opt/flopswap/script/catprocswap.sh");
 }
 
 void MainWindow::on_pushButtonSwapUsage_clicked()
 {
-    m_process->start("sh opt/flopswap/script/swapused.sh");
+    m_process->start("sudo /opt/flopswap/script/swapused.sh");
 }
 
 void MainWindow::on_actionAbout_triggered()
