@@ -2,14 +2,6 @@
 
 #Made by sixwheeledbeast, Estel, Malkavian, peterleinchen and vi_
 
-# Go root if not
-if [ `id -u` != 0 ] ; then
-              exec  | sudo gainroot <<EOF
-exec sh $0 $*
-EOF
-              exit $?
-fi
-
 # Setup notification banner
 banner(){
 o=org
