@@ -1,12 +1,16 @@
 #include "settings.h"
 #include "ui_settings.h"
 
+#include <QProcess>
 #include <QtCore/QCoreApplication>
 #include <QFileInfo>
 
 Settings::Settings(QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::Settings)
+    ui(new Ui::Settings),
+
+    m_process(new QProcess(this))
+
 {
     ui->setupUi(this);
 
@@ -25,11 +29,11 @@ void Settings::on_checkBoxEventd_clicked()
 {
     if (ui->checkBoxEventd->isChecked())
     {
-        system("sudo cp /opt/flopswap/script/relocateswap /etc/event.d/relocateswap");
+        m_process->start("sudo /opt/flopswap/script/setupstart.sh");
     }
     else
     {
-        system("sudo rm /etc/event.d/relocateswap");
+        m_process->start("sudo /opt/flopswap/script/rmupstart.sh");
     }
 }
 
