@@ -2,6 +2,7 @@
 #define SETTINGS_H
 
 #include <QDialog>
+#include <QProcess>
 
 namespace Ui {
     class Settings;
@@ -21,6 +22,8 @@ private slots:
 
 private:
     Ui::Settings *ui;
+    QProcess *m_process;
+
 };
 
 #endif // SETTINGS_H
